@@ -55,7 +55,7 @@ class TransactionsManager(Manager):
             raise ValueError("method argument should be STANDARD, INLINE or INLINE EMBED")
 
         if self.PASS_ON_TRANSACTION_COST:
-            transaction.amount = transaction.full_transaction_cost(transaction.card_locale)
+            transaction.amount = transaction.full_transaction_cost(transaction.card_locale, self.LOCAL_COST, self.INTL_COST)
 
         data = json.JSONDecoder().decode(transaction.to_json())
 
